@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2015 Andrew M. Bishop
+ This file Copyright 2008-2015, 2018, 2019 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -296,8 +296,8 @@ int main(int argc,char** argv)
     printf("\n");
 
     printf("Included highways  : %s\n",HighwaysNameList(OSMWays->file.highways));
-    printf("Included transports: %s\n",AllowedNameList(OSMWays->file.allow));
-    printf("Included properties: %s\n",PropertiesNameList(OSMWays->file.props));
+    printf("Included transports: %s\n",TransportsNameList(OSMWays->file.transports));
+    printf("Included properties: %s\n",PropertiesNameList(OSMWays->file.properties));
 
     /* Examine the relations */
 
@@ -508,7 +508,7 @@ static void print_node(Nodes *nodes,index_t item)
  printf("Node %"Pindex_t"\n",item);
  printf("  firstseg=%"Pindex_t"\n",nodep->firstseg);
  printf("  latoffset=%d lonoffset=%d (latitude=%.6f longitude=%.6f)\n",nodep->latoffset,nodep->lonoffset,radians_to_degrees(latitude),radians_to_degrees(longitude));
- printf("  allow=%02x (%s)\n",nodep->allow,AllowedNameList(nodep->allow));
+ printf("  allow=%02x (%s)\n",nodep->allow,TransportsNameList(nodep->allow));
  if(IsSuperNode(nodep))
     printf("  Super-Node\n");
  if(nodep->flags & NODE_MINIRNDBT)
@@ -565,7 +565,7 @@ static void print_way(Ways *ways,index_t item)
                                    wayp->type&Highway_OneWay?",One-Way":"",
                                    wayp->type&Highway_CycleBothWays?",Cycle-Both-Ways":"",
                                    wayp->type&Highway_Roundabout?",Roundabout":"");
- printf("  allow=%02x (%s)\n",wayp->allow,AllowedNameList(wayp->allow));
+ printf("  allow=%02x (%s)\n",wayp->allow,TransportsNameList(wayp->allow));
  if(wayp->props)
     printf("  props=%02x (%s)\n",wayp->props,PropertiesNameList(wayp->props));
  if(wayp->speed)
@@ -609,13 +609,13 @@ static void print_turn_relation(Relations *relations,index_t item,Segments *segm
 
     if(seg==relationp->from)
       {
-       from_node=OtherNode(segmentp,relationp->from);
+       from_node=OtherNode(segmentp,relationp->via);
        from_way=segmentp->way;
       }
 
     if(seg==relationp->to)
       {
-       to_node=OtherNode(segmentp,relationp->to);
+       to_node=OtherNode(segmentp,relationp->via);
        to_way=segmentp->way;
       }
 
@@ -628,7 +628,7 @@ static void print_turn_relation(Relations *relations,index_t item,Segments *segm
  printf("  via=%"Pindex_t" (node)\n",relationp->via);
  printf("  to=%"Pindex_t" (segment) = %"Pindex_t" (way) = %"Pindex_t" (node)\n",relationp->to,to_way,to_node);
  if(relationp->except)
-    printf("  except=%02x (%s)\n",relationp->except,AllowedNameList(relationp->except));
+    printf("  except=%02x (%s)\n",relationp->except,TransportsNameList(relationp->except));
 }
 
 
@@ -937,7 +937,7 @@ static void print_turn_relation_osm(Relations *relations,index_t item,Segments *
  printf("    <tag k='restriction' v='%s'/>\n",restriction);
 
  if(relationp->except)
-    printf("    <tag k='except' v='%s' />\n",AllowedNameList(relationp->except));
+    printf("    <tag k='except' v='%s' />\n",TransportsNameList(relationp->except));
 
  printf("    <member type='way' ref='%"Pindex_t"' role='from' />\n",relationp->from+1);
  printf("    <member type='node' ref='%"Pindex_t"' role='via' />\n",relationp->via+1);
@@ -1112,7 +1112,7 @@ static void print_turn_relation_visualiser(Relations *relations,index_t item,Seg
  printf("&nbsp;&nbsp;&nbsp;&lt;tag k='restriction' v='%s'/&gt;\n",restriction);
 
  if(relationp->except)
-    printf("&nbsp;&nbsp;&nbsp;&lt;tag k='except' v='%s' /&gt;\n",AllowedNameList(relationp->except));
+    printf("&nbsp;&nbsp;&nbsp;&lt;tag k='except' v='%s' /&gt;\n",TransportsNameList(relationp->except));
 
  printf("&nbsp;&nbsp;&nbsp;&lt;member type='way' ref='%"Pindex_t"' role='from' /&gt;\n",relationp->from+1);
  printf("&nbsp;&nbsp;&nbsp;&lt;member type='node' ref='%"Pindex_t"' role='via' /&gt;\n",relationp->via+1);
@@ -1155,7 +1155,7 @@ static const char* const months[12]={"Jan","Feb","Mar","Apr","May","Jun","Jul","
 
 static char *RFC822Date(time_t t)
 {
- static char value[32]; /* static allocation of return value */
+ static char value[80]; /* static allocation of return value */
  char weekday[4];
  char month[4];
  struct tm *tim;
