@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2015 Andrew M. Bishop
+ This file Copyright 2008-2015, 2019 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -146,12 +146,12 @@ void printf_program_end(void)
     printf("Finish Program\n");
 
     if(option_logtime==2)
-       printf("[ m:ss.micros] ");
+       printf("[  m:ss.micros] ");
     else if(option_logtime==1)
-       printf("[ m:ss.mil] ");
+       printf("[  m:ss.mil] ");
 
     if(option_logmemory)
-       printf("[RAM,FILE MB] ");
+       printf("[ RAM,FILE MB] ");
 
     if(option_logtime)
        printf("elapsed time");
@@ -567,9 +567,9 @@ static void fprintf_elapsed_time(FILE *file,struct timeval *start)
    }
 
  if(option_logtime==2)
-    fprintf(file,"[%2ld:%02ld.%06ld] ",elapsed.tv_sec/60,elapsed.tv_sec%60,elapsed.tv_usec);
+    fprintf(file,"[%3ld:%02ld.%06ld] ",elapsed.tv_sec/60,elapsed.tv_sec%60,elapsed.tv_usec);
  else
-    fprintf(file,"[%2ld:%02ld.%03ld] ",elapsed.tv_sec/60,elapsed.tv_sec%60,elapsed.tv_usec/1000);
+    fprintf(file,"[%3ld:%02ld.%03ld] ",elapsed.tv_sec/60,elapsed.tv_sec%60,elapsed.tv_usec/1000);
 }
 
 
@@ -585,7 +585,7 @@ static void fprintf_elapsed_time(FILE *file,struct timeval *start)
 
 static void fprintf_max_memory(FILE *file,size_t max_alloc,size_t max_mmap)
 {
- fprintf(file,"[%3zu, %3zu MB] ",max_alloc/(1024*1024),max_mmap/(1024*1024));
+ fprintf(file,"[%4zu,%4zu MB] ",max_alloc/(1024*1024),max_mmap/(1024*1024));
 }
 
 
@@ -605,3 +605,94 @@ void _logassert(const char *message,const char *file,int line)
 
  exit(EXIT_FAILURE);
 }
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  Allocate some memory by calling calloc() and checking for failures.
+
+  void *calloc_logassert Returns the newly allocated pointer.
+
+  size_t nmemb The number of members in the array to allocate.
+
+  size_t size The size of the array to allocate.
+
+  const char *file The file in which the error occured.
+
+  int line The line number in the file at which the error occured.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void *_calloc_logassert(size_t nmemb,size_t size,const char *file,int line)
+{
+ void *temp=calloc(nmemb,size);
+
+ if(!temp)
+   {
+    char string[64];
+
+    sprintf(string,"Failed to allocate %zu bytes of memory",nmemb*size);
+
+    _logassert(string,file,line);
+   }
+
+ return temp;
+}
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  Allocate some memory by calling malloc() and checking for failures.
+
+  void *malloc_logassert Returns the newly allocated pointer.
+
+  size_t size The size of the memory to allocate.
+
+  const char *file The file in which the error occured.
+
+  int line The line number in the file at which the error occured.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void *_malloc_logassert(size_t size,const char *file,int line)
+{
+ void *temp=malloc(size);
+
+ if(!temp)
+   {
+    char string[64];
+
+    sprintf(string,"Failed to allocate %zu bytes of memory",size);
+
+    _logassert(string,file,line);
+   }
+
+ return temp;
+}
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  Allocate some memory by calling realloc() and checking for failures.
+
+  void *realloc_logassert Returns the newly allocated pointer.
+
+  void *ptr An existing pointer to be reallocated.
+
+  size_t size The size of the memory to allocate.
+
+  const char *file The file in which the error occured.
+
+  int line The line number in the file at which the error occured.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void *_realloc_logassert(void *ptr,size_t size,const char *file,int line)
+{
+ void *temp=realloc(ptr,size);
+
+ if(!temp)
+   {
+    char string[64];
+
+    sprintf(string,"Failed to allocate %zu bytes of memory",size);
+
+    _logassert(string,file,line);
+   }
+
+ return temp;
+}
