@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2015 Andrew M. Bishop
+ This file Copyright 2008-2015, 2019 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -512,7 +512,7 @@ static int valid_segment_for_profile(Ways *ways,Segment *segmentp,Profile *profi
  int i;
 
  /* mode of transport must be allowed on the highway */
- if(!(wayp->allow&profile->allow))
+ if(!(wayp->allow&profile->transports))
     return(0);
 
  /* must obey weight restriction (if exists) */
@@ -528,7 +528,7 @@ static int valid_segment_for_profile(Ways *ways,Segment *segmentp,Profile *profi
  segment_pref=profile->highway[HIGHWAY(wayp->type)];
 
  for(i=1;i<Property_Count;i++)
-    if(ways->file.props & PROPERTIES(i))
+    if(ways->file.properties & PROPERTIES(i))
       {
        if(wayp->props & PROPERTIES(i))
           segment_pref*=profile->props_yes[i];
@@ -584,7 +584,7 @@ void GetLatLong(Nodes *nodes,index_t index,Node *nodep,double *latitude,double *
 
  do
    {
-    mid=(start+end)/2;                  /* Choose mid point */
+    mid=start+(end-start)/2;            /* Choose mid point (avoid overflow) */
 
     offset=LookupNodeOffset(nodes,mid);
 
