@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2015 Andrew M. Bishop
+ This file Copyright 2008-2015, 2019 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -147,7 +147,7 @@ index_t FindFirstTurnRelation1(Relations *relations,index_t via)
 
  do
    {
-    mid=(start+end)/2;              /* Choose mid point */
+    mid=start+(end-start)/2;        /* Choose mid point (avoid overflow) */
 
     relation=LookupTurnRelation(relations,mid,1);
 
@@ -265,7 +265,7 @@ index_t FindFirstTurnRelation2(Relations *relations,index_t via,index_t from)
 
  do
    {
-    mid=(start+end)/2;              /* Choose mid point */
+    mid=start+(end-start)/2;        /* Choose mid point (avoid overflow) */
 
     relation=LookupTurnRelation(relations,mid,1);
 
