@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2010-2015 Andrew M. Bishop
+ This file Copyright 2010-2015, 2018, 2019 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -75,15 +75,13 @@ RelationsX *NewRelationList(int append,int readonly)
 {
  RelationsX *relationsx;
 
- relationsx=(RelationsX*)calloc(1,sizeof(RelationsX));
-
- logassert(relationsx,"Failed to allocate memory (try using slim mode?)"); /* Check calloc() worked */
+ relationsx=(RelationsX*)calloc_logassert(1,sizeof(RelationsX));
 
 
  /* Route Relations */
 
- relationsx->rrfilename    =(char*)malloc(strlen(option_tmpdirname)+32);
- relationsx->rrfilename_tmp=(char*)malloc(strlen(option_tmpdirname)+48); /* allow %p to be up to 20 bytes */
+ relationsx->rrfilename    =(char*)malloc_logassert(strlen(option_tmpdirname)+32);
+ relationsx->rrfilename_tmp=(char*)malloc_logassert(strlen(option_tmpdirname)+48); /* allow %p to be up to 20 bytes */
 
  sprintf(relationsx->rrfilename    ,"%s/relationsx.route.parsed.mem",option_tmpdirname);
  sprintf(relationsx->rrfilename_tmp,"%s/relationsx.route.%p.tmp"    ,option_tmpdirname,(void*)relationsx);
@@ -118,8 +116,8 @@ RelationsX *NewRelationList(int append,int readonly)
 
  /* Turn Restriction Relations */
 
- relationsx->trfilename    =(char*)malloc(strlen(option_tmpdirname)+32);
- relationsx->trfilename_tmp=(char*)malloc(strlen(option_tmpdirname)+48); /* allow %p to be up to 20 bytes */
+ relationsx->trfilename    =(char*)malloc_logassert(strlen(option_tmpdirname)+32);
+ relationsx->trfilename_tmp=(char*)malloc_logassert(strlen(option_tmpdirname)+48); /* allow %p to be up to 20 bytes */
 
  sprintf(relationsx->trfilename    ,"%s/relationsx.turn.parsed.mem",option_tmpdirname);
  sprintf(relationsx->trfilename_tmp,"%s/relationsx.turn.%p.tmp"    ,option_tmpdirname,(void*)relationsx);
@@ -230,6 +228,7 @@ void AppendRouteRelationList(RelationsX* relationsx,relation_t id,
                              relation_t *relations,int nrelations)
 {
  RouteRelX relationx={0};
+ uint64_t longsize;
  FILESORT_VARINT size;
  node_t nonode=NO_NODE_ID;
  way_t noway=NO_WAY_ID;
@@ -238,13 +237,16 @@ void AppendRouteRelationList(RelationsX* relationsx,relation_t id,
  relationx.id=id;
  relationx.routes=routes;
 
- size=sizeof(RouteRelX)+(nnodes+1)*sizeof(node_t)+(nways+1)*sizeof(way_t)+(nrelations+1)*sizeof(relation_t);
+ longsize=sizeof(RouteRelX)+1*sizeof(node_t)+(nways+1)*sizeof(way_t)+(nrelations+1)*sizeof(relation_t);
 
- WriteFileBuffered(relationsx->rrfd,&size,FILESORT_VARSIZE);
+ logassert(longsize<FILESORT_MAXINT,"Route relation contains too much data (change FILESORT_VARINT to 32-bits?)"); /* Ensure no overflow of FILESORT_VARINT integer */
+
+ size=longsize;
+
+ WriteFileBuffered(relationsx->rrfd,&size     ,FILESORT_VARSIZE);
  WriteFileBuffered(relationsx->rrfd,&relationx,sizeof(RouteRelX));
 
- WriteFileBuffered(relationsx->rrfd,nodes  ,nnodes*sizeof(node_t));
- WriteFileBuffered(relationsx->rrfd,&nonode,       sizeof(node_t));
+ WriteFileBuffered(relationsx->rrfd,&nonode,sizeof(node_t));
 
  WriteFileBuffered(relationsx->rrfd,ways  ,nways*sizeof(way_t));
  WriteFileBuffered(relationsx->rrfd,&noway,      sizeof(way_t));
@@ -351,13 +353,13 @@ index_t IndexRouteRelX(RelationsX *relationsx,relation_t id)
 
  do
    {
-    mid=(start+end)/2;                  /* Choose mid point */
+    mid=start+(end-start)/2;             /* Choose mid point (avoid overflow) */
 
     if(relationsx->rridata[mid]<id)      /* Mid point is too low */
        start=mid+1;
     else if(relationsx->rridata[mid]>id) /* Mid point is too high */
        end=mid?(mid-1):mid;
-    else                                /* Mid point is correct */
+    else                                 /* Mid point is correct */
        return(mid);
    }
  while((end-start)>1);
@@ -410,7 +412,7 @@ index_t IndexTurnRelX(RelationsX *relationsx,relation_t id)
 
  do
    {
-    mid=(start+end)/2;                   /* Choose mid point */
+    mid=start+(end-start)/2;             /* Choose mid point (avoid overflow) */
 
     if(relationsx->tridata[mid]<id)      /* Mid point is too low */
        start=mid+1;
@@ -743,7 +745,7 @@ void ProcessRouteRelations(RelationsX *relationsx,WaysX *waysx,int keep)
                 ways++;
                }
              else
-                logerror("Route Relation %"Prelation_t" contains Way %"Pway_t" that does not exist in the Routino database (not a highway?).\n",logerror_relation(relationx.id),logerror_way(wayid));
+                logerror("Route Relation %"Prelation_t" contains Way %"Pway_t" that does not exist in the Routino database.\n",logerror_relation(relationx.id),logerror_way(wayid));
             }
          }
 
@@ -758,7 +760,7 @@ void ProcessRouteRelations(RelationsX *relationsx,WaysX *waysx,int keep)
           else if(routes)
             {
              if(nunmatched%256==0)
-                unmatched=(RouteRelX*)realloc((void*)unmatched,(nunmatched+256)*sizeof(RouteRelX));
+                unmatched=(RouteRelX*)realloc_logassert((void*)unmatched,(nunmatched+256)*sizeof(RouteRelX));
 
              unmatched[nunmatched].id=relationid;
              unmatched[nunmatched].routes=routes;
@@ -878,21 +880,21 @@ void ProcessTurnRelations(RelationsX *relationsx,NodesX *nodesx,SegmentsX *segme
 
     if(via==NO_NODE)
       {
-       logerror("Turn Relation %"Prelation_t" contains Node %"Pnode_t" that does not exist in the Routino database (not a highway node?).\n",logerror_relation(relationx.id),logerror_node(relationx.via));
+       logerror("Turn Relation %"Prelation_t" contains Node %"Pnode_t" that does not exist in the Routino database.\n",logerror_relation(relationx.id),logerror_node(relationx.via));
        deleted++;
        goto endloop;
       }
 
     if(from==NO_WAY)
       {
-       logerror("Turn Relation %"Prelation_t" contains Way %"Pway_t" that does not exist in the Routino database (not a highway?).\n",logerror_relation(relationx.id),logerror_way(relationx.from));
+       logerror("Turn Relation %"Prelation_t" contains Way %"Pway_t" that does not exist in the Routino database.\n",logerror_relation(relationx.id),logerror_way(relationx.from));
        deleted++;
        goto endloop;
       }
 
     if(to==NO_WAY)
       {
-       logerror("Turn Relation %"Prelation_t" contains Way %"Pway_t" that does not exist in the Routino database (not a highway?).\n",logerror_relation(relationx.id),logerror_way(relationx.to));
+       logerror("Turn Relation %"Prelation_t" contains Way %"Pway_t" that does not exist in the Routino database.\n",logerror_relation(relationx.id),logerror_way(relationx.to));
        deleted++;
        goto endloop;
       }
