@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2009-2015 Andrew M. Bishop
+ This file Copyright 2009-2015, 2017, 2019 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -76,7 +76,8 @@ typedef struct _thread_data
 #if defined(USE_PTHREADS) && USE_PTHREADS
 
 static pthread_mutex_t running_mutex = PTHREAD_MUTEX_INITIALIZER;
-static pthread_cond_t running_cond = PTHREAD_COND_INITIALIZER;
+static pthread_mutex_t files_mutex   = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t  running_cond  = PTHREAD_COND_INITIALIZER;
 
 #endif
 
@@ -125,11 +126,10 @@ index_t filesort_fixed(int fd_in,int fd_out,size_t itemsize,int (*pre_sort_funct
  int *fds=NULL,*heap=NULL;
  int nfiles=0,ndata=0;
  index_t count_out=0,count_in=0,total=0;
- size_t nitems;
+ size_t nitems,item;
  char *data;
  void **datap;
  thread_data *threads;
- size_t item;
  int i,more=1;
 #if defined(USE_PTHREADS) && USE_PTHREADS
  int nthreads=0;
@@ -137,7 +137,7 @@ index_t filesort_fixed(int fd_in,int fd_out,size_t itemsize,int (*pre_sort_funct
 
  /* Allocate the RAM buffer and other bits */
 
- nitems=SizeFileFD(fd_in)/itemsize;
+ nitems=(size_t)SizeFileFD(fd_in)/itemsize;
 
  if(nitems==0)
     return(0);
@@ -147,17 +147,17 @@ index_t filesort_fixed(int fd_in,int fd_out,size_t itemsize,int (*pre_sort_funct
  else
     nitems=option_filesort_ramsize/(option_filesort_threads*(itemsize+sizeof(void*)));
 
- threads=(thread_data*)calloc(option_filesort_threads,sizeof(thread_data));
+ threads=(thread_data*)calloc_logassert(option_filesort_threads,sizeof(thread_data));
 
  for(i=0;i<option_filesort_threads;i++)
    {
-    threads[i].data=malloc(nitems*itemsize);
-    threads[i].datap=malloc(nitems*sizeof(void*));
+    threads[i].data=malloc_logassert(nitems*itemsize);
+    threads[i].datap=malloc_logassert(nitems*sizeof(void*));
 
-    log_malloc(threads[i].data,nitems*itemsize);
+    log_malloc(threads[i].data ,nitems*itemsize);
     log_malloc(threads[i].datap,nitems*sizeof(void*));
 
-    threads[i].filename=(char*)malloc(strlen(option_tmpdirname)+24);
+    threads[i].filename=(char*)malloc_logassert(strlen(option_tmpdirname)+24);
 
     threads[i].itemsize=itemsize;
     threads[i].compare=compare_function;
@@ -296,6 +296,11 @@ index_t filesort_fixed(int fd_in,int fd_out,size_t itemsize,int (*pre_sort_funct
 
 #endif
 
+ /* Shortcut if there are no files */
+
+ if(nfiles==0)
+    goto tidy_and_exit;
+
  /* Shortcut if only one file, lucky for us we still have the data in RAM) */
 
  if(nfiles==1)
@@ -320,7 +325,7 @@ index_t filesort_fixed(int fd_in,int fd_out,size_t itemsize,int (*pre_sort_funct
 
  /* Open all of the temporary files */
 
- fds=(int*)malloc(nfiles*sizeof(int));
+ fds=(int*)malloc_logassert(nfiles*sizeof(int));
 
  for(i=0;i<nfiles;i++)
    {
@@ -335,7 +340,7 @@ index_t filesort_fixed(int fd_in,int fd_out,size_t itemsize,int (*pre_sort_funct
 
  /* Perform an n-way merge using a binary heap */
 
- heap=(int*)malloc((1+nfiles)*sizeof(int));
+ heap=(int*)malloc_logassert((1+nfiles)*sizeof(int));
 
  data =threads[0].data;
  datap=threads[0].datap;
@@ -503,12 +508,11 @@ index_t filesort_vary(int fd_in,int fd_out,int (*pre_sort_function)(void*,index_
  int *fds=NULL,*heap=NULL;
  int nfiles=0,ndata=0;
  index_t count_out=0,count_in=0,total=0;
- size_t datasize;
+ size_t datasize,item;
  FILESORT_VARINT nextitemsize,largestitemsize=0;
  char *data;
  void **datap;
  thread_data *threads;
- size_t item;
  int i,more=1;
 #if defined(USE_PTHREADS) && USE_PTHREADS
  int nthreads=0;
@@ -516,7 +520,7 @@ index_t filesort_vary(int fd_in,int fd_out,int (*pre_sort_function)(void*,index_
 
  /* Allocate the RAM buffer and other bits */
 
- datasize=SizeFileFD(fd_in);
+ datasize=(size_t)SizeFileFD(fd_in);
 
  if(datasize==0)
     return(0);
@@ -530,16 +534,18 @@ index_t filesort_vary(int fd_in,int fd_out,int (*pre_sort_function)(void*,index_
  else
     datasize=option_filesort_ramsize/option_filesort_threads;
 
- threads=(thread_data*)calloc(option_filesort_threads,sizeof(thread_data));
+ datasize=FILESORT_VARALIGN*((datasize+FILESORT_VARALIGN-1)/FILESORT_VARALIGN);
+
+ threads=(thread_data*)calloc_logassert(option_filesort_threads,sizeof(thread_data));
 
  for(i=0;i<option_filesort_threads;i++)
    {
-    threads[i].data=malloc(datasize);
+    threads[i].data=malloc_logassert(datasize);
     threads[i].datap=NULL;
 
     log_malloc(threads[i].data,datasize);
 
-    threads[i].filename=(char*)malloc(strlen(option_tmpdirname)+24);
+    threads[i].filename=(char*)malloc_logassert(strlen(option_tmpdirname)+24);
 
     threads[i].compare=compare_function;
    }
@@ -596,7 +602,7 @@ index_t filesort_vary(int fd_in,int fd_out,int (*pre_sort_function)(void*,index_
 
           ramused+=itemsize;
 
-          ramused =FILESORT_VARALIGN*((ramused+FILESORT_VARSIZE-1)/FILESORT_VARALIGN);
+          ramused =FILESORT_VARALIGN*((ramused+FILESORT_VARALIGN-1)/FILESORT_VARALIGN);
           ramused+=FILESORT_VARALIGN-FILESORT_VARSIZE;
 
           total++;
@@ -699,6 +705,11 @@ index_t filesort_vary(int fd_in,int fd_out,int (*pre_sort_function)(void*,index_
 
 #endif
 
+ /* Shortcut if there are no files */
+
+ if(nfiles==0)
+    goto tidy_and_exit;
+
  /* Shortcut if only one file, lucky for us we still have the data in RAM) */
 
  if(nfiles==1)
@@ -721,13 +732,13 @@ index_t filesort_vary(int fd_in,int fd_out,int (*pre_sort_function)(void*,index_
 
  /* Check that number of files is less than file size */
 
- largestitemsize=FILESORT_VARALIGN*(1+(largestitemsize+FILESORT_VARALIGN-FILESORT_VARSIZE)/FILESORT_VARALIGN);
+ largestitemsize=FILESORT_VARALIGN*((largestitemsize+FILESORT_VARALIGN-1)/FILESORT_VARALIGN);
 
- logassert((unsigned)nfiles<((datasize-nfiles*sizeof(void*))/largestitemsize),"Too many temporary files (use more sorting memory?)");
+ logassert((unsigned)nfiles<((datasize-nfiles*sizeof(void*))/(FILESORT_VARALIGN+largestitemsize)),"Too many temporary files (use more sorting memory?)");
 
  /* Open all of the temporary files */
 
- fds=(int*)malloc(nfiles*sizeof(int));
+ fds=(int*)malloc_logassert(nfiles*sizeof(int));
 
  for(i=0;i<nfiles;i++)
    {
@@ -742,7 +753,7 @@ index_t filesort_vary(int fd_in,int fd_out,int (*pre_sort_function)(void*,index_
 
  /* Perform an n-way merge using a binary heap */
 
- heap=(int*)malloc((1+nfiles)*sizeof(int));
+ heap=(int*)malloc_logassert((1+nfiles)*sizeof(int));
 
  data=threads[0].data;
  datap=(void**)(data+datasize-nfiles*sizeof(void*));
@@ -754,7 +765,7 @@ index_t filesort_vary(int fd_in,int fd_out,int (*pre_sort_function)(void*,index_
     int index;
     FILESORT_VARINT itemsize;
 
-    datap[i]=data+FILESORT_VARALIGN-FILESORT_VARSIZE+i*largestitemsize;
+    datap[i]=data+FILESORT_VARALIGN+i*(largestitemsize+FILESORT_VARALIGN);
 
     ReadFileBuffered(fds[i],&itemsize,FILESORT_VARSIZE);
 
@@ -904,6 +915,13 @@ static void *filesort_fixed_heapsort_thread(thread_data *thread)
 
  /* Create a temporary file and write the result */
 
+#if defined(USE_PTHREADS) && USE_PTHREADS
+
+ if(option_filesort_threads>1)
+    pthread_mutex_lock(&files_mutex);
+
+#endif
+
  fd=OpenFileBufferedNew(thread->filename);
 
  for(item=0;item<thread->n;item++)
@@ -915,6 +933,8 @@ static void *filesort_fixed_heapsort_thread(thread_data *thread)
 
  if(option_filesort_threads>1)
    {
+    pthread_mutex_unlock(&files_mutex);
+
     pthread_mutex_lock(&running_mutex);
 
     thread->running=2;
@@ -949,6 +969,13 @@ static void *filesort_vary_heapsort_thread(thread_data *thread)
 
  /* Create a temporary file and write the result */
 
+#if defined(USE_PTHREADS) && USE_PTHREADS
+
+ if(option_filesort_threads>1)
+    pthread_mutex_lock(&files_mutex);
+
+#endif
+
  fd=OpenFileBufferedNew(thread->filename);
 
  for(item=0;item<thread->n;item++)
@@ -964,6 +991,8 @@ static void *filesort_vary_heapsort_thread(thread_data *thread)
 
  if(option_filesort_threads>1)
    {
+    pthread_mutex_unlock(&files_mutex);
+
     pthread_mutex_lock(&running_mutex);
 
     thread->running=2;
@@ -1041,7 +1070,7 @@ void filesort_heapsort(void **datap,size_t nitems,int(*compare_function)(const v
     while((2*index)<(item-1))
       {
        int newindex;
-       void *temp;
+       void **temp;
 
        newindex=2*index;
 
