@@ -13,7 +13,7 @@ Routino router web page.
 
 Part of the Routino routing software.
 
-This file Copyright 2008-2015 Andrew M. Bishop
+This file Copyright 2008-2018 Andrew M. Bishop
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -85,18 +85,30 @@ Select start and end points (click on the marker icons below), select routing pr
 <td>(EN)
 <td><input name="language" type="radio" value="en" onchange="formSetLanguage();" >
 <tr>
+<td><a id="lang_cs_url" href="router.html.cs" title="Česky webpage">Česky</a>
+<td>(CS)
+<td><input name="language" type="radio" value="cs" onchange="formSetLanguage();" >
+<tr>
 <td><a id="lang_de_url" href="router.html.de" title="Deutsche Webseite">Deutsch</a>
 <td>(DE)
 <td><input name="language" type="radio" value="de" onchange="formSetLanguage();" >
 <tr>
+<td><a id="lang_es_url" href="router.html.es" title="Español webpage">Español</a>
+<td>(ES)
+<td><input name="language" type="radio" value="es" onchange="formSetLanguage();" >
+<tr>
 <td><a id="lang_fr_url" href="router.html.fr" title="Page web en français">Français</a>
 <td>(FR)
 <td><input name="language" type="radio" value="fr" onchange="formSetLanguage();" >
 <tr>
-<td><a id="lang_hu_url" href="router.html.hu" title="Magyar weblap">Magyar</a>
+<td><a id="lang_hu_url" href="router.html.hu" title="Magyar weboldal">Magyar</a>
 <td>(HU)
 <td><input name="language" type="radio" value="hu" onchange="formSetLanguage();" >
 <tr>
+<td><a id="lang_it_url" href="router.html.it" title="Italiano webpage">Italiano</a>
+<td>(IT)
+<td><input name="language" type="radio" value="it" onchange="formSetLanguage();" >
+<tr>
 <td><a id="lang_nl_url" href="router.html.nl" title="Nederlandse web pagina">Nederlands</a>
 <td>(NL)
 <td><input name="language" type="radio" value="nl" onchange="formSetLanguage();" >
@@ -105,7 +117,11 @@ Select start and end points (click on the marker icons below), select routing pr
 <td>(PL)
 <td><input name="language" type="radio" value="pl" onchange="formSetLanguage();" checked>
 <tr>
-<td><a id="lang_ru_url" href="router.html.ru" title="Русский">Русский</a>
+<td><a id="lang_pt_url" href="router.html.pt" title="Português webpage">Português</a>
+<td>(PT)
+<td>
+<tr>
+<td><a id="lang_ru_url" href="router.html.ru" title="Страница на Русском языке">Русский</a>
 <td>(RU)
 <td><input name="language" type="radio" value="ru" onchange="formSetLanguage();" >
 </table>
@@ -121,23 +137,23 @@ Select start and end points (click on the marker icons below), select routing pr
 <div id="waypoints">
 <div id="waypointXXX" class="waypoint" style="display: none;">
 <img id="iconXXX" class="waypoint-icon" src="icons/marker-XXX-grey.png" title="Waypoint XXX Position" alt="Waypoint XXX" onmouseup="markerToggleMap(XXX);" draggable="true">
-<span id="coordsXXX">
-<input name="lonXXX" type="text" size="7" title="Waypoint XXX Longitude" onchange="formSetCoords(XXX);">E
+<span id="coordsXXX" style="display: none;">
+<input name="lonXXX" type="text" size="6" title="Waypoint XXX Longitude" onchange="formSetCoords(XXX);">E
 <input name="latXXX" type="text" size="7" title="Waypoint XXX Latitude" onchange="formSetCoords(XXX);">N
 </span>
-<span id="searchXXX" style="display: none;">
+<span id="searchXXX">
 <input name="searchXXX" type="text" size="18" title="Waypoint XXX Location"> <!-- uses Javascript event for triggering -->
 </span>
 <div class="waypoint-buttons" style="display: inline-block;">
 <img alt="?" src="icons/waypoint-search.png" title="Znajdź miejsce" onmousedown="markerSearch(XXX);" >
 <img alt="G" src="icons/waypoint-locate.png" title="Pobierz aktualna lokalizację" onmousedown="markerLocate(XXX);" >
 <img alt="O" src="icons/waypoint-recentre.png" title="Wycentruj mapę na tym punkcie" onmousedown="markerRecentre(XXX);">
-<img alt="^" src="icons/waypoint-up.png" title="Move this waypoint up" onmousedown="markerMoveUp(XXX);" >
-<img alt="+" src="icons/waypoint-add.png" title="Add waypoint after this one" onmousedown="markerAddAfter(XXX);">
+<img alt="^" src="icons/waypoint-up.png" title="Przenieś ten punkt wyżej" onmousedown="markerMoveUp(XXX);" >
+<img alt="+" src="icons/waypoint-add.png" title="Dodaj punkt po tym" onmousedown="markerAddAfter(XXX);">
 <br>
-<img alt="#" src="icons/waypoint-coords.png" title="Coordinates for location" onmousedown="markerCoords(XXX);" >
+<img alt="#" src="icons/waypoint-coords.png" title="Współrzędne dla lokalizacji" onmousedown="markerCoords(XXX);" >
 <img alt="~" src="icons/waypoint-home.png" title="Współrzędne lokalizacji" onmousedown="markerHome(XXX);" >
-<img alt="o" src="icons/waypoint-centre.png" title="Centre this waypoint on map" onmousedown="markerCentre(XXX);" >
+<img alt="o" src="icons/waypoint-centre.png" title="Wyśrodkuj ten punkt na mapie" onmousedown="markerCentre(XXX);" >
 <img alt="v" src="icons/waypoint-down.png" title="Move this waypoint down" onmousedown="markerMoveDown(XXX);">
 <img alt="-" src="icons/waypoint-remove.png" title="Remove this waypoint" onmousedown="markerRemove(XXX);" >
 </div>
@@ -158,6 +174,12 @@ Select start and end points (click on the marker icons below), select routing pr
 </div>
 </div>
 
+<div class="hideshow_box">
+<span class="hideshow_title">Znajdź</span>
+<input type="button" title="Znajdź najkrótsza trasę" id="shortest1" value="Najkrótsza trasa" onclick="findRoute('shortest');" disabled="disabled">
+<input type="button" title="Znajdź najdłuższą trasę" id="quickest1" value="Najszybsza trasa" onclick="findRoute('quickest');" disabled="disabled">
+</div>
+
 <div class="hideshow_box">
 <span id="hideshow_transport_show" onclick="hideshow_show('transport');" class="hideshow_hide">+</span>
 <span id="hideshow_transport_hide" onclick="hideshow_hide('transport');" class="hideshow_show">-</span>
@@ -172,7 +194,7 @@ Select start and end points (click on the marker icons below), select routing pr
 <tr><td>Motocykl:<td><input name="transport" type="radio" value="motorcycle" onchange="formSetTransport('motorcycle');">
 <tr><td>Samochód: <td><input name="transport" type="radio" value="motorcar" onchange="formSetTransport('motorcar' );">
 <tr><td>Goods: <td><input name="transport" type="radio" value="goods" onchange="formSetTransport('goods' );">
-<tr><td>HGV: <td><input name="transport" type="radio" value="hgv" onchange="formSetTransport('hgv' );">
+<tr><td>Pojazd ciężarowy: <td><input name="transport" type="radio" value="hgv" onchange="formSetTransport('hgv' );">
 <tr><td>Pojazd użyteczności publicznej: <td><input name="transport" type="radio" value="psv" onchange="formSetTransport('psv' );">
 </table>
 </div>
@@ -227,7 +249,7 @@ Select start and end points (click on the marker icons below), select routing pr
 <div class="hideshow_box">
 <span id="hideshow_property_show" onclick="hideshow_show('property');" class="hideshow_show">+</span>
 <span id="hideshow_property_hide" onclick="hideshow_hide('property');" class="hideshow_hide">-</span>
-<span class="hideshow_title">Property Preferences</span>
+<span class="hideshow_title">Ustawienia zmiennych</span>
 <div id="hideshow_property_div" style="display: none;">
 <table>
 <tr><td>Paved: <td><input name="property-paved" type="text" size="3" onchange="formSetProperty('paved' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetProperty('paved' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetProperty('paved' ,'+');">
@@ -258,12 +280,6 @@ Select start and end points (click on the marker icons below), select routing pr
 </div>
 </div>
 
-<div class="hideshow_box">
-<span class="hideshow_title">Znajdź</span>
-<input type="button" title="Znajdź najkrótsza trasę" id="shortest" value="Najkrótsza trasa" onclick="findRoute('shortest');" disabled="disabled">
-<input type="button" title="Znajdź najdłuższą trasę" id="quickest" value="Najszybsza trasa" onclick="findRoute('quickest');" disabled="disabled">
-</div>
-
 <div class="hideshow_box">
 <span class="hideshow_title">Połączenia</span>
 <a id="permalink_url" href="router.html">Link to this map view</a>
@@ -363,6 +379,12 @@ one-way restrictions (e.g. if walking).
 </div>
 </div>
 
+<div class="hideshow_box">
+<span class="hideshow_title">Znajdź</span>
+<input type="button" title="Znajdź najkrótsza trasę" id="shortest2" value="Najkrótsza trasa" onclick="findRoute('shortest');" disabled="disabled">
+<input type="button" title="Znajdź najdłuższą trasę" id="quickest2" value="Najszybsza trasa" onclick="findRoute('quickest');" disabled="disabled">
+</div>
+
 <div class="hideshow_box">
 <span id="hideshow_shortest_show" onclick="hideshow_show('shortest');" class="hideshow_show">+</span>
 <span id="hideshow_shortest_hide" onclick="hideshow_hide('shortest');" class="hideshow_hide">-</span>
