@@ -3,7 +3,7 @@
 //
 // Part of the Routino routing software.
 //
-// This file Copyright 2008-2016 Andrew M. Bishop
+// This file Copyright 2008-2019 Andrew M. Bishop
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU Affero General Public License as published by
@@ -599,8 +599,8 @@ function formSetCoords(marker,lon,lat) // called from router.html (with one argu
     document.forms["form"].elements["lon" + marker].value=format5f(lon);
     document.forms["form"].elements["lat" + marker].value=format5f(lat);
 
-    routino.point[marker].lon=lon;
-    routino.point[marker].lat=lat;
+    routino.point[marker].lon=format5f(lon);
+    routino.point[marker].lat=format5f(lat);
     routino.point[marker].used=true;
 
     markerCheckHome(marker);
@@ -1124,6 +1124,9 @@ function dragWaypointMapDrop(e)
 
  if(!routino.point[dragged_marker].active)
     markerToggleMap(dragged_marker);
+
+ if(routino.point[dragged_marker].search=="")
+    markerCoords(dragged_marker);
 }
 
 
@@ -1145,8 +1148,6 @@ function markerToggleMap(marker) // called from router.html
    }
 
  markerAddRemoveMap(marker,!routino.point[marker].active);
-
- updateSearchButtons();
 }
 
 
@@ -1180,6 +1181,8 @@ function markerAddMap(marker)
  markersmoved=true;
 
  updateURLs();
+
+ updateSearchButtons();
 }
 
 
@@ -1199,6 +1202,8 @@ function markerRemoveMap(marker)
  markersmoved=true;
 
  updateURLs();
+
+ updateSearchButtons();
 }
 
 
@@ -1667,7 +1672,7 @@ function markerRemoveForm(marker)
 function markerClearForm(marker)
 {
  markerRemoveMap(marker);
- markerCoords(marker);
+ markerSearch(marker);
 
  formSetCoords(marker,"","");
  formSetSearch(marker,"");
@@ -1998,8 +2003,12 @@ function runGPXSuccess(response)
  else
     colour="#0000FF";
 
- layerGPX[routing_type] = L.multiPolyline(coords,{weight: 3, stroke: true, color: colour, opacity: 1.0,
-                                                  fill: false});
+ if(typeof(L.multiPolyline)=="function")
+    layerGPX[routing_type] = L.multiPolyline(coords,{weight: 3, stroke: true, color: colour, opacity: 1.0,
+                                                     fill: false});
+ else
+    layerGPX[routing_type] = L.polyline(coords,{weight: 3, stroke: true, color: colour, opacity: 1.0,
+                                                fill: false});
 
  map.addLayer(layerGPX[routing_type]);
 }
