@@ -3,7 +3,7 @@
 //
 // Part of the Routino routing software.
 //
-// This file Copyright 2008-2016 Andrew M. Bishop
+// This file Copyright 2008-2019 Andrew M. Bishop
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU Affero General Public License as published by
@@ -572,38 +572,39 @@ function formSetCoords(marker,lon,lat) // called from router.html (with one argu
 
     if(lon==="")
       {
-       lonlat=map.getCenter().clone();
-       lonlat.transform(epsg900913,epsg4326);
+       lonlat=ol.proj.toLonLat(map.getView().getCenter());
 
-       lon=lonlat.lon;
+       lon=lonlat[0];
       }
+    else
+       lon=Number(lon);
 
     if(lon<-180) lon=-180;
     if(lon>+180) lon=+180;
 
     if(lat==="")
       {
-       lonlat=map.getCenter().clone();
-       lonlat.transform(epsg900913,epsg4326);
+       lonlat=ol.proj.toLonLat(map.getView().getCenter());
 
-       lat=lonlat.lat;
+       lat=lonlat[1];
       }
+    else
+       lat=Number(lat);
 
     if(lat<-90 ) lat=-90 ;
     if(lat>+90 ) lat=+90 ;
 
-    lonlat = new OpenLayers.LonLat(lon,lat);
-    lonlat.transform(epsg4326,epsg900913);
+    lonlat = ol.proj.fromLonLat([lon,lat]);
 
-    markers[marker].move(lonlat);
+    markers[marker].setGeometry(new ol.geom.Point(lonlat));
 
     markersmoved=true;
 
     document.forms["form"].elements["lon" + marker].value=format5f(lon);
     document.forms["form"].elements["lat" + marker].value=format5f(lat);
 
-    routino.point[marker].lon=lon;
-    routino.point[marker].lat=lat;
+    routino.point[marker].lon=format5f(lon);
+    routino.point[marker].lat=format5f(lat);
     routino.point[marker].used=true;
 
     markerCheckHome(marker);
@@ -730,12 +731,11 @@ function buildURLArguments(lang)
 
 function buildMapArguments()
 {
- var lonlat = map.getCenter().clone();
- lonlat.transform(epsg900913,epsg4326);
+ var lonlat = ol.proj.toLonLat(map.getView().getCenter());
 
- var zoom = map.getZoom() + map.minZoomLevel;
+ var zoom = map.getView().getZoom();
 
- return "lat=" + format5f(lonlat.lat) + ";lon=" + format5f(lonlat.lon) + ";zoom=" + zoom;
+ return "lat=" + format5f(lonlat[1]) + ";lon=" + format5f(lonlat[0]) + ";zoom=" + zoom;
 }
 
 
@@ -776,7 +776,6 @@ function updateURLs()
 
 var map;
 var layerMap=[], layerVectors, layerGPX;
-var epsg4326, epsg900913;
 var routing_type;
 
 //
@@ -787,89 +786,57 @@ function map_init()             // called from router.html
 {
  // Create the map (Map URLs and limits are in mapprops.js)
 
- epsg4326=new OpenLayers.Projection("EPSG:4326");
- epsg900913=new OpenLayers.Projection("EPSG:900913");
+ var extent = ol.extent.boundingExtent([ol.proj.fromLonLat([mapprops.westedge,mapprops.southedge]),
+                                        ol.proj.fromLonLat([mapprops.eastedge,mapprops.northedge])]);
 
- map = new OpenLayers.Map ("map",
-                           {
-                            controls:[
-                                      new OpenLayers.Control.Navigation(),
-                                      new OpenLayers.Control.PanZoomBar(),
-                                      new OpenLayers.Control.ScaleLine(),
-                                      new OpenLayers.Control.LayerSwitcher()
-                                      ],
-
-                            projection: epsg900913,
-                            displayProjection: epsg4326,
-
-                            minZoomLevel: mapprops.zoomout,
-                            numZoomLevels: mapprops.zoomin-mapprops.zoomout+1,
-                            maxResolution: 156543.03390625 / Math.pow(2,mapprops.zoomout),
-
-                            restrictedExtent: new OpenLayers.Bounds(mapprops.westedge,mapprops.southedge,mapprops.eastedge,mapprops.northedge).transform(epsg4326,epsg900913)
-                           });
-
- // Get a URL for the tile (mostly copied from OpenLayers/Layer/XYZ.js).
-
- function limitedUrl(bounds)
- {
-  var res = this.map.getResolution();
-
-  var x = Math.round((bounds.left - this.maxExtent.left) / (res * this.tileSize.w));
-  var y = Math.round((this.maxExtent.top - bounds.top) / (res * this.tileSize.h));
-  var z = this.map.getZoom() + this.map.minZoomLevel;
-
-  var limit = Math.pow(2, z);
-  x = ((x % limit) + limit) % limit;
-
-  var xyz = {"x": x, "y": y, "z": z};
-  var url = this.url;
-
-  if (OpenLayers.Util.isArray(url))
-    {
-     var s = "" + xyz.x + xyz.y + xyz.z;
-     url = this.selectUrl(s, url);
-    }
-
-  return OpenLayers.String.format(url, xyz);
- }
+ map = new ol.Map({target: "map",
+                   view: new ol.View({minZoom: mapprops.zoomout,
+                                      maxZoom: mapprops.zoomin,
+                                      extent: extent}),
+                   controls: []
+                 });
 
  // Add map tile layers
 
  for(var l=0; l<mapprops.mapdata.length; l++)
    {
+    mapprops.mapdata[l].tiles.url=mapprops.mapdata[l].tiles.url.replace(/\$\{/g,"{");
     var urls;
 
-    if(OpenLayers.Util.isArray(mapprops.mapdata[l].tiles.subdomains))
+    if(mapprops.mapdata[l].tiles.subdomains===undefined)
+       urls=[mapprops.mapdata[l].tiles.url];
+    else
       {
        urls=[];
 
        for(var s=0; s<mapprops.mapdata[l].tiles.subdomains.length; s++)
-          urls.push(mapprops.mapdata[l].tiles.url.replace(/\${s}/,mapprops.mapdata[l].tiles.subdomains[s]));
+          urls.push(mapprops.mapdata[l].tiles.url.replace(/\{s}/,mapprops.mapdata[l].tiles.subdomains[s]));
       }
-    else
-       urls=mapprops.mapdata[l].tiles.url;
 
-    layerMap[l] = new OpenLayers.Layer.TMS(mapprops.mapdata[l].label,
-                                           urls,
-                                           {
-                                            getURL: limitedUrl,
-                                            displayOutsideMaxExtent: true,
-                                            buffer: 1
-                                           });
+    layerMap[l] = new ol.layer.Tile({title: mapprops.mapdata[l].label,
+                                     type: 'base',
+                                     source: new ol.source.XYZ({urls: urls}),
+                                     visible: l?false:true});
+
     map.addLayer(layerMap[l]);
    }
 
+ // Add the controls
+
+ map.addControl(new ol.control.Zoom());
+ map.addControl(new ol.control.ScaleLine());
+ map.addControl(new ol.control.LayerSwitcher());
+
  // Update the attribution if the layer changes
 
  function change_attribution_event(event)
  {
   for(var l=0; l<mapprops.mapdata.length; l++)
-     if(layerMap[l] == event.layer)
+     if(layerMap[l].getVisible())
         change_attribution(l);
  }
 
- map.events.register("changelayer",layerMap,change_attribution_event);
+ map.getLayerGroup().on("change", change_attribution_event);
 
  function change_attribution(l)
  {
@@ -888,12 +855,12 @@ function map_init()             // called from router.html
 
  layerGPX={shortest: null, quickest: null};
 
- gpx_style={shortest: new OpenLayers.Style({},{strokeWidth: 3, strokeColor: "#00FF00"}),
-            quickest: new OpenLayers.Style({},{strokeWidth: 3, strokeColor: "#0000FF"})};
+ gpx_style={shortest: new ol.style.Style({stroke: new ol.style.Stroke({width: 3, color: "#00FF00"})}),
+            quickest: new ol.style.Style({stroke: new ol.style.Stroke({width: 3, color: "#0000FF"})})};
 
  // Add a vectors layer
 
- layerVectors = new OpenLayers.Layer.Vector("Markers",{displayInLayerSwitcher: false});
+ layerVectors = new ol.layer.Vector({source: new ol.source.Vector()});
  map.addLayer(layerVectors);
 
  // A set of markers
@@ -904,38 +871,35 @@ function map_init()             // called from router.html
 
  for(var marker=1;marker<=mapprops.maxmarkers;marker++)
    {
-    markers[marker] = new OpenLayers.Feature.Vector(new OpenLayers.Geometry.Point(0,0),{},
-                                                    new OpenLayers.Style({},{externalGraphic: "icons/marker-" + marker + "-red.png",
-                                                                             fillColor: "white",
-                                                                             graphicYOffset: -25,
-                                                                             graphicWidth: 21,
-                                                                             graphicHeight: 25,
-                                                                             display: "none"}));
+    markers[marker] = new ol.Feature();
 
-    layerVectors.addFeatures([markers[marker]]);
+    var style = new ol.style.Style({image: new ol.style.Icon({src: "icons/marker-" + marker + "-red.png",
+                                                              anchor: [0.5,1.0]})});
+
+    markers[marker].setStyle(style);
    }
 
  // A function to drag the markers
 
- var drag = new OpenLayers.Control.DragFeature(layerVectors,
-                                               {onDrag:     dragMarkerMove,
-                                                onComplete: dragMarkerComplete });
- map.addControl(drag);
- drag.activate();
+ var modify = new ol.interaction.Modify({source: layerVectors.getSource()});
+
+ map.addInteraction(modify);
+
+ modify.on('modifyend', function(evt) { dragMarkerComplete(layerVectors.getSource().getClosestFeatureToCoordinate(evt.mapBrowserEvent.coordinate)); });
 
  // Markers to highlight a selected point
 
  for(var highlight in highlights)
    {
-    highlights[highlight] = new OpenLayers.Feature.Vector(new OpenLayers.Geometry.Point(0,0),{},
-                                                          new OpenLayers.Style({},{strokeColor: route_dark_colours[highlight],
-                                                                                   fillColor: "white",
-                                                                                   pointRadius: 10,
-                                                                                   strokeWidth: 4,
-                                                                                   fillOpacity: 0,
-                                                                                   display: "none"}));
+    highlights[highlight] = new ol.Feature();
 
-    layerVectors.addFeatures([highlights[highlight]]);
+    var style = new ol.style.Style({image: new ol.style.Circle({stroke: new ol.style.Stroke({width: 4,
+                                                                                             color: route_dark_colours[highlight]}),
+                                                                radius: 10})});
+
+    highlights[highlight].setStyle(style);
+
+    layerVectors.getSource().addFeature(highlights[highlight]);
    }
 
  // A popup for routing results
@@ -945,7 +909,7 @@ function map_init()             // called from router.html
 
  // Move the map
 
- map.events.register("moveend", map, updateURLs);
+ map.on("moveend", updateURLs, map);
 
  var lon =args["lon"];
  var lat =args["lat"];
@@ -962,16 +926,11 @@ function map_init()             // called from router.html
     if(zoom<mapprops.zoomout) zoom=mapprops.zoomout;
     if(zoom>mapprops.zoomin)  zoom=mapprops.zoomin;
 
-    var lonlat = new OpenLayers.LonLat(lon,lat);
-    lonlat.transform(epsg4326,epsg900913);
-
-    map.moveTo(lonlat,zoom-map.minZoomLevel);
+    map.getView().setCenter(ol.proj.fromLonLat([Number(lon),Number(lat)]));
+    map.getView().setZoom(zoom);
    }
  else
-   {
-    map.setCenter(map.restrictedExtent.getCenterLonLat(), map.getZoomForExtent(map.restrictedExtent,true));
-    map.maxResolution = map.getResolution();
-   }
+    map.getView().fit(extent,map.getSize());
 
  // Unhide editing URL if variable set
 
@@ -991,9 +950,9 @@ function map_init()             // called from router.html
 // Callback for a marker drag occuring on the map.
 //
 
-function dragMarkerMove(feature,pixel)
+function dragMarkerMove(feature)
 {
- for(var marker in markers)
+ for(var marker=1;marker<=mapprops.maxmarkers;marker++)
     if(feature==markers[marker])
        dragMarkerSetForm(marker);
 }
@@ -1003,9 +962,9 @@ function dragMarkerMove(feature,pixel)
 // Callback for completing a marker drag on the map.
 //
 
-function dragMarkerComplete(feature,pixel)
+function dragMarkerComplete(feature)
 {
- for(var marker in markers)
+ for(var marker=1;marker<=mapprops.maxmarkers;marker++)
     if(feature==markers[marker])
        dragMarkerSetForm(marker);
 
@@ -1019,10 +978,9 @@ function dragMarkerComplete(feature,pixel)
 
 function dragMarkerSetForm(marker)
 {
- var lonlat = new OpenLayers.LonLat(markers[marker].geometry.x, markers[marker].geometry.y);
- lonlat.transform(epsg900913,epsg4326);
+ var lonlat = ol.proj.toLonLat(markers[marker].getGeometry().getFlatCoordinates());
 
- formSetCoords(marker,lonlat.lon,lonlat.lat);
+ formSetCoords(marker,lonlat[0],lonlat[1]);
 }
 
 
@@ -1184,14 +1142,18 @@ function dragWaypointMapDrop(e)
 
  var rect = document.getElementById("map").getBoundingClientRect();
 
- var lonlat = map.getLonLatFromViewPortPx(new OpenLayers.Pixel(e.clientX-rect.left-window.scrollX-dragged_icon_x+8,
-                                                               e.clientY-rect.top -window.scrollY-dragged_icon_y+21));
- lonlat.transform(epsg900913,epsg4326);
+ var coord = map.getCoordinateFromPixel([e.clientX-rect.left-window.scrollX-dragged_icon_x+8,
+                                         e.clientY-rect.top -window.scrollY-dragged_icon_y+21]);
 
- formSetCoords(dragged_marker,lonlat.lon,lonlat.lat);
+ var lonlat = ol.proj.toLonLat(coord);
+
+ formSetCoords(dragged_marker,lonlat[0],lonlat[1]);
 
  if(!routino.point[dragged_marker].active)
     markerToggleMap(dragged_marker);
+
+ if(routino.point[dragged_marker].search=="")
+    markerCoords(dragged_marker);
 }
 
 
@@ -1213,8 +1175,6 @@ function markerToggleMap(marker) // called from router.html
    }
 
  markerAddRemoveMap(marker,!routino.point[marker].active);
-
- updateSearchButtons();
 }
 
 
@@ -1239,7 +1199,8 @@ function markerAddMap(marker)
 {
  clearSearchResult(marker);
 
- markers[marker].style.display = "";
+ if(!layerVectors.getSource().hasFeature(markers[marker]))
+    layerVectors.getSource().addFeature(markers[marker]);
  routino.point[marker].active=true;
  routino.point[marker].used=true;
 
@@ -1248,6 +1209,8 @@ function markerAddMap(marker)
  markersmoved=true;
 
  updateURLs();
+
+ updateSearchButtons();
 }
 
 
@@ -1259,7 +1222,8 @@ function markerRemoveMap(marker)
 {
  clearSearchResult(marker);
 
- markers[marker].style.display = "none";
+ if(layerVectors.getSource().hasFeature(markers[marker]))
+    layerVectors.getSource().removeFeature(markers[marker]);
  routino.point[marker].active=false;
 
  updateIcon(marker);
@@ -1267,6 +1231,8 @@ function markerRemoveMap(marker)
  markersmoved=true;
 
  updateURLs();
+
+ updateSearchButtons();
 }
 
 
@@ -1307,10 +1273,9 @@ function markerCentre(marker)   // called from router.html
 
  clearSearchResult(marker);
 
- var lonlat=map.getCenter().clone();
- lonlat.transform(epsg900913,epsg4326);
+ var lonlat = ol.proj.toLonLat(map.getView().getCenter());
 
- formSetCoords(marker,lonlat.lon,lonlat.lat);
+ formSetCoords(marker,lonlat[0],lonlat[1]);
 }
 
 
@@ -1325,13 +1290,12 @@ function markerRecentre(marker) // called from router.html
 
  clearSearchResult(marker);
 
- var lon=routino.point[marker].lon;
- var lat=routino.point[marker].lat;
+ var lon=Number(routino.point[marker].lon);
+ var lat=Number(routino.point[marker].lat);
 
- var lonlat = new OpenLayers.LonLat(lon,lat);
- lonlat.transform(epsg4326,epsg900913);
+ var lonlat = ol.proj.fromLonLat([lon,lat]);
 
- map.panTo(lonlat);
+ map.getView().setCenter(lonlat);
 }
 
 
@@ -1482,7 +1446,10 @@ function updateIcon(marker)
     else
        document.getElementById("icon" + marker).src="icons/marker-home-grey.png";
 
-    markers[marker].style.externalGraphic="icons/marker-home-red.png";
+    var style = new ol.style.Style({image: new ol.style.Icon({src: "icons/marker-home-red.png",
+                                                              anchor: [0.5,1.0]})});
+
+    markers[marker].setStyle(style);
    }
  else
    {
@@ -1491,10 +1458,11 @@ function updateIcon(marker)
     else
        document.getElementById("icon" + marker).src="icons/marker-" + marker + "-grey.png";
 
-    markers[marker].style.externalGraphic="icons/marker-" + marker + "-red.png";
-   }
+    var style = new ol.style.Style({image: new ol.style.Icon({src: "icons/marker-" + marker + "-red.png",
+                                                              anchor: [0.5,1.0]})});
 
- layerVectors.drawFeature(markers[marker]);
+    markers[marker].setStyle(style);
+   }
 }
 
 
@@ -1737,7 +1705,7 @@ function markerRemoveForm(marker)
 function markerClearForm(marker)
 {
  markerRemoveMap(marker);
- markerCoords(marker);
+ markerSearch(marker);
 
  formSetCoords(marker,"","");
  formSetSearch(marker,"");
@@ -1771,35 +1739,33 @@ function highlight(type,line,action)
 {
  if(action == "clear")
    {
-    highlights[type].style.display = "none";
+    if(layerVectors.getSource().hasFeature(highlights[type]))
+       layerVectors.getSource().removeFeature(highlights[type]);
 
     drawPopup(type,null);
    }
  else if(action == "zoom")
    {
-    var lonlat = new OpenLayers.LonLat(routepoints[type][line].lon,routepoints[type][line].lat);
-    lonlat.transform(epsg4326,epsg900913);
+    var lonlat = ol.proj.fromLonLat([routepoints[type][line].lon,routepoints[type][line].lat]);
 
-    map.moveTo(lonlat,map.numZoomLevels-2);
+    map.getView().setCenter(lonlat);
+    map.getView().setZoom(mapprops.zoomin-2);
    }
  else
    {
     // Marker
 
-    var lonlat = new OpenLayers.LonLat(routepoints[type][line].lon,routepoints[type][line].lat);
-    lonlat.transform(epsg4326,epsg900913);
+    var lonlat = ol.proj.fromLonLat([routepoints[type][line].lon,routepoints[type][line].lat]);
 
-    highlights[type].move(lonlat);
+    highlights[type].setGeometry(new ol.geom.Point(lonlat));
 
-    if(highlights[type].style.display == "none")
-       highlights[type].style.display = "";
+    if(!layerVectors.getSource().hasFeature(highlights[type]))
+       layerVectors.getSource().addFeature(highlights[type]);
 
     // Popup
 
     drawPopup(type,"<table>" + routepoints[type][line].html + "</table>");
    }
-
- layerVectors.drawFeature(highlights[type]);
 }
 
 
@@ -1872,7 +1838,6 @@ function drawPopup(type,html)
 function removeGPXTrace(type)
 {
  map.removeLayer(layerGPX[type]);
- layerGPX[type].destroy();
  layerGPX[type]=null;
 
  displayStatus(type,"no_info");
@@ -2032,14 +1997,8 @@ function runRouterSuccess(response)
 
  var url="results.cgi?uuid=" + uuid + ";type=" + routing_type + ";format=gpx-track";
 
- layerGPX[routing_type] = new OpenLayers.Layer.Vector("GPX (" + routing_type + ")",
-                                                      {
-                                                       displayInLayerSwitcher: false,
-                                                       protocol:   new OpenLayers.Protocol.HTTP({url: url, format: new OpenLayers.Format.GPX()}),
-                                                       strategies: [new OpenLayers.Strategy.Fixed()],
-                                                       style:      gpx_style[routing_type],
-                                                       projection: map.displayProjection
-                                                      });
+ layerGPX[routing_type] = new ol.layer.Vector({source: new ol.source.Vector({url: url, format: new ol.format.GPX()}),
+                                               style: gpx_style[routing_type]});
 
  map.addLayer(layerGPX[routing_type]);
 
@@ -2218,16 +2177,15 @@ function DoSearch(marker)
 
  var search=routino.point[marker].search;
 
- var mapbounds=map.getExtent().clone();
- mapbounds.transform(epsg900913,epsg4326);
+ var mapbounds=map.calculateExtent();
 
  var url="search.cgi";
 
  url=url + "?marker=" + marker;
- url=url + ";lonmin=" + format5f(mapbounds.left);
- url=url + ";latmin=" + format5f(mapbounds.bottom);
- url=url + ";lonmax=" + format5f(mapbounds.right);
- url=url + ";latmax=" + format5f(mapbounds.top);
+ url=url + ";lonmin=" + format5f(ol.proj.toLonLat([mapbounds[0],mapbounds[1]])[0]);
+ url=url + ";latmin=" + format5f(ol.proj.toLonLat([mapbounds[0],mapbounds[1]])[1]);
+ url=url + ";lonmax=" + format5f(ol.proj.toLonLat([mapbounds[2],mapbounds[3]])[0]);
+ url=url + ";latmax=" + format5f(ol.proj.toLonLat([mapbounds[2],mapbounds[3]])[1]);
  url=url + ";search=" + encodeURIComponent(search);
 
  ajaxGET(url,runSearchSuccess);
