@@ -13,7 +13,7 @@ Routino data visualiser web page.
 
 Part of the Routino routing software.
 
-This file Copyright 2008-2014 Andrew M. Bishop
+This file Copyright 2008-2017 Andrew M. Bishop
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -83,22 +83,34 @@ Only data relevant for routing is displayed and some will therefore be excluded.
 <td><a id="lang_en_url" href="visualiser.html.en" title="English language webpage">English</a>
 <td>(EN)
 <tr>
+<td><a id="lang_cs_url" href="visualiser.html.cs" title="Česky webpage">Česky</a>
+<td>(CS)
+<tr>
 <td><a id="lang_de_url" href="visualiser.html.de" title="Deutsche Webseite">Deutsch</a>
 <td>(DE)
 <tr>
+<td><a id="lang_es_url" href="visualiser.html.es" title="Español webpage">Español</a>
+<td>(ES)
+<tr>
 <td><a id="lang_fr_url" href="visualiser.html.fr" title="Page web en français">Français</a>
 <td>(FR)
 <tr>
-<td><a id="lang_hu_url" href="visualiser.html.hu" title="Magyar weblap">Magyar</a>
+<td><a id="lang_hu_url" href="visualiser.html.hu" title="Magyar weboldal">Magyar</a>
 <td>(HU)
 <tr>
+<td><a id="lang_it_url" href="visualiser.html.it" title="Italiano webpage">Italiano</a>
+<td>(IT)
+<tr>
 <td><a id="lang_nl_url" href="visualiser.html.nl" title="Nederlandse web pagina">Nederlands</a>
 <td>(NL)
 <tr>
 <td><a id="lang_pl_url" href="visualiser.html.pl" title="Polski webpage">Polski</a>
 <td>(PL)
 <tr>
-<td><a id="lang_ru_url" href="visualiser.html.ru" title="Русский">Русский</a>
+<td><a id="lang_pt_url" href="visualiser.html.pt" title="Português webpage">Português</a>
+<td>(PT)
+<tr>
+<td><a id="lang_ru_url" href="visualiser.html.ru" title="Страница на Русском языке">Русский</a>
 <td>(RU)
 </table>
 <a target="translation" href="http://www.routino.org/translations/">Routino Translations</a>
@@ -246,7 +258,7 @@ Each segment allowed for the chosen type of transport is drawn.
 <tr><td>Motocykl:<td><input name="transport" type="radio" value="motorcycle" onchange="displayData('transport');">
 <tr><td>Samochód: <td><input name="transport" type="radio" value="motorcar" onchange="displayData('transport');" checked>
 <tr><td>Goods: <td><input name="transport" type="radio" value="goods" onchange="displayData('transport');">
-<tr><td>HGV: <td><input name="transport" type="radio" value="hgv" onchange="displayData('transport');">
+<tr><td>Pojazd ciężarowy: <td><input name="transport" type="radio" value="hgv" onchange="displayData('transport');">
 <tr><td>Pojazd użyteczności publicznej: <td><input name="transport" type="radio" value="psv" onchange="displayData('transport');">
 </table>
 </form>
@@ -269,7 +281,7 @@ Each barrier blocking the chosen type of transport is drawn.
 <tr><td>Motocykl:<td><input name="barrier" type="radio" value="motorcycle" onchange="displayData('barrier');">
 <tr><td>Samochód: <td><input name="barrier" type="radio" value="motorcar" onchange="displayData('barrier');" checked>
 <tr><td>Goods: <td><input name="barrier" type="radio" value="goods" onchange="displayData('barrier');">
-<tr><td>HGV: <td><input name="barrier" type="radio" value="hgv" onchange="displayData('barrier');">
+<tr><td>Pojazd ciężarowy: <td><input name="barrier" type="radio" value="hgv" onchange="displayData('barrier');">
 <tr><td>Pojazd użyteczności publicznej: <td><input name="barrier" type="radio" value="psv" onchange="displayData('barrier');">
 </table>
 </form>
