@@ -3,7 +3,7 @@
 //
 // Part of the Routino routing software.
 //
-// This file Copyright 2008-2014 Andrew M. Bishop
+// This file Copyright 2008-2014, 2019 Andrew M. Bishop
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU Affero General Public License as published by
@@ -647,6 +647,26 @@ function displayData(datatype)  // called from visualiser.html
 }
 
 
+//
+// Add a bounding box
+//
+
+function addBox(words)
+{
+ var lat1=words[0];
+ var lon1=words[1];
+ var lat2=words[2];
+ var lon2=words[3];
+
+ var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
+
+ layerBoxes.setBounds(bounds);
+
+ layerBoxes.setStyle({stroke: true});
+ box=true;
+}
+
+
 //
 // Success in getting the junctions.
 //
@@ -673,19 +693,7 @@ function runJunctionsSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -723,19 +731,7 @@ function runSuperSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -787,19 +783,7 @@ function runWaytypeSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -856,19 +840,7 @@ function runHighwaySuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -906,19 +878,7 @@ function runTransportSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -956,19 +916,7 @@ function runBarrierSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -1003,19 +951,7 @@ function runTurnsSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -1058,19 +994,7 @@ function runLimitSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -1138,19 +1062,7 @@ function runPropertySuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
@@ -1188,19 +1100,7 @@ function runErrorlogSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = L.latLngBounds(L.latLng(lat1,lon1),L.latLng(lat2,lon2));
-
-       layerBoxes.setBounds(bounds);
-
-       layerBoxes.setStyle({stroke: true});
-       box=true;
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
