@@ -3,7 +3,7 @@
 //
 // Part of the Routino routing software.
 //
-// This file Copyright 2008-2014 Andrew M. Bishop
+// This file Copyright 2008-2014, 2019 Andrew M. Bishop
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU Affero General Public License as published by
@@ -84,9 +84,7 @@ if(location.search.length>1)
 
 var map;
 var layerMap=[], layerHighlights, layerVectors, layerBoxes;
-var epsg4326, epsg900913;
-var box;
-var select;
+
 
 //
 // Initialise the 'map' object
@@ -96,89 +94,57 @@ function map_init()             // called from visualiser.html
 {
  // Create the map (Map URLs and limits are in mapprops.js)
 
- epsg4326=new OpenLayers.Projection("EPSG:4326");
- epsg900913=new OpenLayers.Projection("EPSG:900913");
+ var extent = ol.extent.boundingExtent([ol.proj.fromLonLat([mapprops.westedge,mapprops.southedge]),
+                                        ol.proj.fromLonLat([mapprops.eastedge,mapprops.northedge])]);
 
- map = new OpenLayers.Map ("map",
-                           {
-                            controls:[
-                                      new OpenLayers.Control.Navigation(),
-                                      new OpenLayers.Control.PanZoomBar(),
-                                      new OpenLayers.Control.ScaleLine(),
-                                      new OpenLayers.Control.LayerSwitcher()
-                                      ],
-
-                            projection: epsg900913,
-                            displayProjection: epsg4326,
-
-                            minZoomLevel: mapprops.zoomout,
-                            numZoomLevels: mapprops.zoomin-mapprops.zoomout+1,
-                            maxResolution: 156543.03390625 / Math.pow(2,mapprops.zoomout),
-
-                            restrictedExtent: new OpenLayers.Bounds(mapprops.westedge,mapprops.southedge,mapprops.eastedge,mapprops.northedge).transform(epsg4326,epsg900913)
-                           });
-
- // Get a URL for the tile (mostly copied from OpenLayers/Layer/XYZ.js).
-
- function limitedUrl(bounds)
- {
-  var res = this.map.getResolution();
-
-  var x = Math.round((bounds.left - this.maxExtent.left) / (res * this.tileSize.w));
-  var y = Math.round((this.maxExtent.top - bounds.top) / (res * this.tileSize.h));
-  var z = this.map.getZoom() + this.map.minZoomLevel;
-
-  var limit = Math.pow(2, z);
-  x = ((x % limit) + limit) % limit;
-
-  var xyz = {"x": x, "y": y, "z": z};
-  var url = this.url;
-
-  if (OpenLayers.Util.isArray(url))
-    {
-     var s = "" + xyz.x + xyz.y + xyz.z;
-     url = this.selectUrl(s, url);
-    }
-
-  return OpenLayers.String.format(url, xyz);
- }
+ map = new ol.Map({target: "map",
+                   view: new ol.View({minZoom: mapprops.zoomout,
+                                      maxZoom: mapprops.zoomin,
+                                      extent: extent}),
+                   controls: []
+                 });
 
  // Add map tile layers
 
  for(var l=0; l<mapprops.mapdata.length; l++)
    {
+    mapprops.mapdata[l].tiles.url=mapprops.mapdata[l].tiles.url.replace(/\$\{/g,"{");
     var urls;
 
-    if(OpenLayers.Util.isArray(mapprops.mapdata[l].tiles.subdomains))
+    if(mapprops.mapdata[l].tiles.subdomains===undefined)
+       urls=[mapprops.mapdata[l].tiles.url];
+    else
       {
        urls=[];
 
        for(var s=0; s<mapprops.mapdata[l].tiles.subdomains.length; s++)
-          urls.push(mapprops.mapdata[l].tiles.url.replace(/\${s}/,mapprops.mapdata[l].tiles.subdomains[s]));
+          urls.push(mapprops.mapdata[l].tiles.url.replace(/\{s}/,mapprops.mapdata[l].tiles.subdomains[s]));
       }
-    else
-       urls=mapprops.mapdata[l].tiles.url;
 
-    layerMap[l] = new OpenLayers.Layer.TMS(mapprops.mapdata[l].label,
-                                           urls,
-                                           {
-                                            getURL: limitedUrl,
-                                            displayOutsideMaxExtent: true,
-                                            buffer: 1
-                                           });
+    layerMap[l] = new ol.layer.Tile({title: mapprops.mapdata[l].label,
+                                     type: 'base',
+                                     source: new ol.source.XYZ({urls: urls}),
+                                     visible: l?false:true});
+
     map.addLayer(layerMap[l]);
    }
 
+ // Add the controls
+
+ map.addControl(new ol.control.Zoom());
+ map.addControl(new ol.control.ScaleLine());
+ map.addControl(new ol.control.LayerSwitcher());
+
  // Update the attribution if the layer changes
 
  function change_attribution_event(event)
  {
   for(var l=0; l<mapprops.mapdata.length; l++)
-     if(layerMap[l] == event.layer)
+     if(layerMap[l].getVisible())
         change_attribution(l);
  }
 
- map.events.register("changelayer",layerMap,change_attribution_event);
+ map.getLayerGroup().on("change", change_attribution_event);
 
  function change_attribution(l)
  {
@@ -195,32 +161,29 @@ function map_init()             // called from visualiser.html
 
  // Add two vectors layers (one for highlights that display behind the vectors)
 
- layerHighlights = new OpenLayers.Layer.Vector("Highlights",{displayInLayerSwitcher: false});
+ layerHighlights = new ol.layer.Vector({source: new ol.source.Vector()});
+
  map.addLayer(layerHighlights);
 
- layerVectors = new OpenLayers.Layer.Vector("Markers",{displayInLayerSwitcher: false});
+ layerVectors = new ol.layer.Vector({source: new ol.source.Vector()});
+
  map.addLayer(layerVectors);
 
  // Handle feature selection and popup
 
- select = new OpenLayers.Control.SelectFeature(layerVectors,
-                                               {onSelect: selectFeature, onUnselect: unselectFeature});
-
- map.addControl(select);
- select.activate();
+ map.on("click", function(e) { var first=true; map.forEachFeatureAtPixel(e.pixel, function (feature, layer) { if(first) selectFeature(feature); first=false; }) });
 
  createPopup();
 
  // Add a boxes layer
 
- layerBoxes = new OpenLayers.Layer.Boxes("Boundary",{displayInLayerSwitcher: false});
- map.addLayer(layerBoxes);
+ layerBoxes = new ol.layer.Vector({source: new ol.source.Vector()});
 
- box=null;
+ map.addLayer(layerBoxes);
 
  // Move the map
 
- map.events.register("moveend", map, updateURLs);
+ map.on("moveend", updateURLs, map);
 
  var lon =args["lon"];
  var lat =args["lat"];
@@ -237,16 +200,11 @@ function map_init()             // called from visualiser.html
     if(zoom<mapprops.zoomout) zoom=mapprops.zoomout;
     if(zoom>mapprops.zoomin)  zoom=mapprops.zoomin;
 
-    var lonlat = new OpenLayers.LonLat(lon,lat);
-    lonlat.transform(epsg4326,epsg900913);
-
-    map.moveTo(lonlat,zoom-map.minZoomLevel);
+    map.getView().setCenter(ol.proj.fromLonLat([Number(lon),Number(lat)]));
+    map.getView().setZoom(zoom);
    }
  else
-   {
-    map.setCenter(map.restrictedExtent.getCenterLonLat(), map.getZoomForExtent(map.restrictedExtent,true));
-    map.maxResolution = map.getResolution();
-   }
+    map.getView().fit(extent,map.getSize());
 
  // Unhide editing URL if variable set
 
@@ -292,12 +250,11 @@ function format5f(number)
 
 function buildMapArguments()
 {
- var lonlat = map.getCenter().clone();
- lonlat.transform(epsg900913,epsg4326);
+ var lonlat = ol.proj.toLonLat(map.getView().getCenter());
 
- var zoom = map.getZoom() + map.minZoomLevel;
+ var zoom = map.getView().getZoom();
 
- return "lat=" + format5f(lonlat.lat) + ";lon=" + format5f(lonlat.lon) + ";zoom=" + zoom;
+ return "lat=" + format5f(lonlat[1]) + ";lon=" + format5f(lonlat[0]) + ";zoom=" + zoom;
 }
 
 
@@ -400,17 +357,25 @@ function drawPopup(html)
 
 function selectFeature(feature)
 {
- if(feature.attributes.dump)
-    ajaxGET("visualiser.cgi?dump=" + feature.attributes.dump, runDumpSuccess);
+ if(feature.get('dump'))
+    ajaxGET("visualiser.cgi?dump=" + feature.get('dump'), runDumpSuccess);
 
- layerHighlights.destroyFeatures();
+ layerHighlights.getSource().clear();
 
- var highlight_style = new OpenLayers.Style({},{strokeColor: "#F0F000",strokeWidth: 8,
-                                                fillColor: "#F0F000",pointRadius: 4});
+ var style;
 
- var highlight = new OpenLayers.Feature.Vector(feature.geometry.clone(),{},highlight_style);
+ if(feature.get('highlight'))
+    style = feature.get('highlight');
+ else
+    style = new ol.style.Style({stroke: new ol.style.Stroke({width: 8, color: "#F0F000"}),
+                                image: new ol.style.Circle({fill: new ol.style.Fill({color: "#F0F000"}),
+                                                            radius: 5})});
 
- layerHighlights.addFeatures([highlight]);
+ var highlight = new ol.Feature(feature.getGeometry());
+
+ highlight.setStyle(style);
+
+ layerHighlights.getSource().addFeature(highlight);
 }
 
 
@@ -420,7 +385,7 @@ function selectFeature(feature)
 
 function unselectFeature(feature)
 {
- layerHighlights.destroyFeatures();
+ layerHighlights.getSource().clear();
 
  drawPopup(null);
 }
@@ -558,14 +523,10 @@ function displayData(datatype)  // called from visualiser.html
 
  unselectFeature();
 
- select.deactivate();
+ layerVectors.getSource().clear();
+ layerHighlights.getSource().clear();
 
- layerVectors.destroyFeatures();
- layerHighlights.destroyFeatures();
-
- if(box !== null)
-    layerBoxes.removeMarker(box);
- box=null;
+ layerBoxes.getSource().clear();
 
  // Print the status
 
@@ -578,15 +539,14 @@ function displayData(datatype)  // called from visualiser.html
 
  // Get the new data
 
- var mapbounds=map.getExtent().clone();
- mapbounds.transform(epsg900913,epsg4326);
+ var mapbounds=map.getView().calculateExtent(map.getSize());
 
  var url="visualiser.cgi";
 
- url=url + "?lonmin=" + format5f(mapbounds.left);
- url=url + ";latmin=" + format5f(mapbounds.bottom);
- url=url + ";lonmax=" + format5f(mapbounds.right);
- url=url + ";latmax=" + format5f(mapbounds.top);
+ url=url + "?lonmin=" + format5f(ol.proj.toLonLat([mapbounds[0],mapbounds[1]])[0]);
+ url=url + ";latmin=" + format5f(ol.proj.toLonLat([mapbounds[0],mapbounds[1]])[1]);
+ url=url + ";lonmax=" + format5f(ol.proj.toLonLat([mapbounds[2],mapbounds[3]])[0]);
+ url=url + ";latmax=" + format5f(ol.proj.toLonLat([mapbounds[2],mapbounds[3]])[1]);
  url=url + ";data=" + datatype;
 
  // Use AJAX to get the data
@@ -661,6 +621,35 @@ function displayData(datatype)  // called from visualiser.html
 }
 
 
+//
+// Add a bounding box
+//
+
+function addBox(words)
+{
+ var lat1=Number(words[0]);
+ var lon1=Number(words[1]);
+ var lat2=Number(words[2]);
+ var lon2=Number(words[3]);
+
+ var box = new ol.Feature();
+
+ var geometry = new ol.geom.LineString([ol.proj.fromLonLat([lon1,lat1]),
+                                        ol.proj.fromLonLat([lon1,lat2]),
+                                        ol.proj.fromLonLat([lon2,lat2]),
+                                        ol.proj.fromLonLat([lon2,lat1]),
+                                        ol.proj.fromLonLat([lon1,lat1])]);
+
+ var style = new ol.style.Style({stroke: new ol.style.Stroke({width: 2, color: "red"})});
+
+ box.setGeometry(geometry);
+
+ box.setStyle(style);
+
+ layerBoxes.getSource().addFeature(box);
+}
+
+
 //
 // Success in getting the junctions.
 //
@@ -685,9 +674,8 @@ function runJunctionsSuccess(response)
  var styles={};
 
  for(var colour in junction_colours)
-    styles[colour]=new OpenLayers.Style({},{stroke: false,
-                                            pointRadius: 2,fillColor: junction_colours[colour],
-                                            cursor: "pointer"});
+    styles[colour] = new ol.style.Style({image: new ol.style.Circle({fill: new ol.style.Fill({color: junction_colours[colour]}),
+                                                                     radius: 2})});
 
  var features=[];
 
@@ -696,36 +684,25 @@ function runJunctionsSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat=words[1];
-       var lon=words[2];
+       var lat=Number(words[1]);
+       var lon=Number(words[2]);
        var count=words[3];
 
-       var lonlat= new OpenLayers.LonLat(lon,lat).transform(epsg4326,epsg900913);
+       var geometry = new ol.geom.Point(ol.proj.fromLonLat([lon,lat]));
 
-       var point = new OpenLayers.Geometry.Point(lonlat.lon,lonlat.lat);
+       var feature = new ol.Feature({geometry: geometry, dump: dump});
 
-       features.push(new OpenLayers.Feature.Vector(point,{dump: dump},styles[count]));
+       feature.setStyle(styles[count]);
+
+       features.push(feature);
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","junctions",lines.length-2);
 }
@@ -739,63 +716,56 @@ function runSuperSuccess(response)
 {
  var lines=response.responseText.split("\n");
 
- var node_style = new OpenLayers.Style({},{stroke: false,
-                                           pointRadius: 4,fillColor: "#FF0000",
-                                           cursor: "pointer"});
+ var node_style = new ol.style.Style({image: new ol.style.Circle({fill: new ol.style.Fill({color: "#FF0000"}),
+                                                                  radius: 4})});
 
- var segment_style = new OpenLayers.Style({},{fill: false,
-                                              strokeWidth: 2,strokeColor: "#FF0000",
-                                              cursor: "pointer"});
+ var highlight_style = new ol.style.Style({image: new ol.style.Circle({fill: new ol.style.Fill({color: "#F0F000"}),
+                                                                       radius: 8})});
+
+ var segment_style = new ol.style.Style({stroke: new ol.style.Stroke({width: 2, color: "#FF0000"})});
 
  var features=[];
 
- var nodepoint;
+ var nodelonlat;
 
  for(var line=0;line<lines.length;line++)
    {
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat=words[1];
-       var lon=words[2];
-
-       var lonlat= new OpenLayers.LonLat(lon,lat).transform(epsg4326,epsg900913);
-
-       var point = new OpenLayers.Geometry.Point(lonlat.lon,lonlat.lat);
+       var lat=Number(words[1]);
+       var lon=Number(words[2]);
 
        if(dump.charAt(0) == "n")
          {
-          nodepoint=point;
+          nodelonlat = ol.proj.fromLonLat([lon,lat]);
 
-          features.push(new OpenLayers.Feature.Vector(point,{dump: dump},node_style));
+          var geometry = new ol.geom.Point(nodelonlat);
+
+          var feature = new ol.Feature({geometry: geometry, dump: dump, highlight: highlight_style});
+
+          feature.setStyle(node_style);
+
+          features.push(feature);
          }
        else
          {
-          var segment = new OpenLayers.Geometry.LineString([nodepoint,point]);
+          var geometry = new ol.geom.LineString([ol.proj.fromLonLat([lon,lat]),nodelonlat]);
 
-          features.push(new OpenLayers.Feature.Vector(segment,{dump: dump},segment_style));
+          var feature = new ol.Feature({geometry: geometry, dump: dump});
+
+          feature.setStyle(segment_style);
+
+          features.push(feature);
          }
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","super",lines.length-2);
 }
@@ -819,56 +789,44 @@ function runWaytypeSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat1=words[1];
-       var lon1=words[2];
-       var lat2=words[3];
-       var lon2=words[4];
+       var lat1=Number(words[1]);
+       var lon1=Number(words[2]);
+       var lat2=Number(words[3]);
+       var lon2=Number(words[4]);
 
-       var lonlat1 = new OpenLayers.LonLat(lon1,lat1).transform(epsg4326,epsg900913);
-       var lonlat2 = new OpenLayers.LonLat(lon2,lat2).transform(epsg4326,epsg900913);
+       var lonlat1 = ol.proj.fromLonLat([lon1,lat1]);
+       var lonlat2 = ol.proj.fromLonLat([lon2,lat2]);
 
-     //var point1 = new OpenLayers.Geometry.Point(lonlat1.lon,lonlat1.lat);
-       var point2 = new OpenLayers.Geometry.Point(lonlat2.lon,lonlat2.lat);
-
-       var dlat = lonlat2.lat-lonlat1.lat;
-       var dlon = lonlat2.lon-lonlat1.lon;
+       var dlat = lonlat2[1]-lonlat1[1];
+       var dlon = lonlat2[0]-lonlat1[0];
        var dist = Math.sqrt(dlat*dlat+dlon*dlon)/10;
        var ang  = Math.atan2(dlat,dlon);
 
-       var point3 = new OpenLayers.Geometry.Point(lonlat1.lon+dlat/dist,lonlat1.lat-dlon/dist);
-       var point4 = new OpenLayers.Geometry.Point(lonlat1.lon-dlat/dist,lonlat1.lat+dlon/dist);
+       var lonlat3 = [lonlat1[0]+dlat/dist,lonlat1[1]-dlon/dist];
+       var lonlat4 = [lonlat1[0]-dlat/dist,lonlat1[1]+dlon/dist];
 
        var r=Math.round(7.5+7.9*Math.cos(ang));
        var g=Math.round(7.5+7.9*Math.cos(ang+2.0943951));
        var b=Math.round(7.5+7.9*Math.cos(ang-2.0943951));
        var colour = "#" + hex[r] + hex[g] + hex[b];
 
-       var segment = new OpenLayers.Geometry.LineString([point2,point3,point4,point2]);
+       var geometry = new ol.geom.LineString([lonlat2,lonlat3,lonlat4,lonlat2]);
 
-       var style=new OpenLayers.Style({},{strokeWidth: 2,strokeColor: colour, cursor: "pointer"});
+       var style = new ol.style.Style({stroke: new ol.style.Stroke({width: 2, color: colour})});
 
-       features.push(new OpenLayers.Feature.Vector(segment,{dump: dump},style));
+       var feature = new ol.Feature({geometry: geometry, dump: dump});
+
+       feature.setStyle(style);
+
+       features.push(feature);
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","waytype",lines.length-2);
 }
@@ -882,9 +840,7 @@ function runHighwaySuccess(response)
 {
  var lines=response.responseText.split("\n");
 
- var style = new OpenLayers.Style({},{fill: false,
-                                      strokeWidth: 2,strokeColor: "#FF0000",
-                                      cursor: "pointer"});
+ var style = new ol.style.Style({stroke: new ol.style.Stroke({width: 2, color: "#FF0000"})});
 
  var features=[];
 
@@ -893,41 +849,29 @@ function runHighwaySuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat1=words[1];
-       var lon1=words[2];
-       var lat2=words[3];
-       var lon2=words[4];
+       var lat1=Number(words[1]);
+       var lon1=Number(words[2]);
+       var lat2=Number(words[3]);
+       var lon2=Number(words[4]);
 
-       var lonlat1= new OpenLayers.LonLat(lon1,lat1).transform(epsg4326,epsg900913);
-       var lonlat2= new OpenLayers.LonLat(lon2,lat2).transform(epsg4326,epsg900913);
+       var lonlat1 = ol.proj.fromLonLat([lon1,lat1]);
+       var lonlat2 = ol.proj.fromLonLat([lon2,lat2]);
 
-       var point1 = new OpenLayers.Geometry.Point(lonlat1.lon,lonlat1.lat);
-       var point2 = new OpenLayers.Geometry.Point(lonlat2.lon,lonlat2.lat);
+       var geometry = new ol.geom.LineString([lonlat1,lonlat2]);
 
-       var segment = new OpenLayers.Geometry.LineString([point1,point2]);
+       var feature = new ol.Feature({geometry: geometry, dump: dump});
 
-       features.push(new OpenLayers.Feature.Vector(segment,{dump: dump},style));
+       feature.setStyle(style);
+
+       features.push(feature);
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","highway",lines.length-2);
 }
@@ -941,9 +885,7 @@ function runTransportSuccess(response)
 {
  var lines=response.responseText.split("\n");
 
- var style = new OpenLayers.Style({},{fill: false,
-                                      strokeWidth: 2,strokeColor: "#FF0000",
-                                      cursor: "pointer"});
+ var style = new ol.style.Style({stroke: new ol.style.Stroke({width: 2, color: "#FF0000"})});
 
  var features=[];
 
@@ -952,41 +894,29 @@ function runTransportSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat1=words[1];
-       var lon1=words[2];
-       var lat2=words[3];
-       var lon2=words[4];
+       var lat1=Number(words[1]);
+       var lon1=Number(words[2]);
+       var lat2=Number(words[3]);
+       var lon2=Number(words[4]);
 
-       var lonlat1= new OpenLayers.LonLat(lon1,lat1).transform(epsg4326,epsg900913);
-       var lonlat2= new OpenLayers.LonLat(lon2,lat2).transform(epsg4326,epsg900913);
+       var lonlat1 = ol.proj.fromLonLat([lon1,lat1]);
+       var lonlat2 = ol.proj.fromLonLat([lon2,lat2]);
 
-       var point1 = new OpenLayers.Geometry.Point(lonlat1.lon,lonlat1.lat);
-       var point2 = new OpenLayers.Geometry.Point(lonlat2.lon,lonlat2.lat);
+       var geometry = new ol.geom.LineString([lonlat1,lonlat2]);
 
-       var segment = new OpenLayers.Geometry.LineString([point1,point2]);
+       var feature = new ol.Feature({geometry: geometry, dump: dump});
 
-       features.push(new OpenLayers.Feature.Vector(segment,{dump: dump},style));
+       feature.setStyle(style);
+
+       features.push(feature);
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","transport",lines.length-2);
 }
@@ -1000,9 +930,8 @@ function runBarrierSuccess(response)
 {
  var lines=response.responseText.split("\n");
 
- var style = new OpenLayers.Style({},{stroke: false,
-                                      pointRadius: 3,fillColor: "#FF0000",
-                                      cursor: "pointer"});
+ var style = new ol.style.Style({image: new ol.style.Circle({fill: new ol.style.Fill({color: "#FF0000"}),
+                                                             radius: 3})});
 
  var features=[];
 
@@ -1011,35 +940,24 @@ function runBarrierSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat=words[1];
-       var lon=words[2];
+       var lat=Number(words[1]);
+       var lon=Number(words[2]);
 
-       var lonlat= new OpenLayers.LonLat(lon,lat).transform(epsg4326,epsg900913);
+       var geometry = new ol.geom.Point(ol.proj.fromLonLat([lon,lat]));
 
-       var point = new OpenLayers.Geometry.Point(lonlat.lon,lonlat.lat);
+       var feature = new ol.Feature({geometry: geometry, dump: dump});
 
-       features.push(new OpenLayers.Feature.Vector(point,{dump: dump},style));
+       feature.setStyle(style);
+
+       features.push(feature);
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","barrier",lines.length-2);
 }
@@ -1053,9 +971,7 @@ function runTurnsSuccess(response)
 {
  var lines=response.responseText.split("\n");
 
- var style = new OpenLayers.Style({},{fill: false,
-                                      strokeWidth: 2,strokeColor: "#FF0000",
-                                      cursor: "pointer"});
+ var style = new ol.style.Style({stroke: new ol.style.Stroke({width: 2, color: "#FF0000"})});
 
  var features=[];
 
@@ -1064,45 +980,32 @@ function runTurnsSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat1=words[1];
-       var lon1=words[2];
-       var lat2=words[3];
-       var lon2=words[4];
-       var lat3=words[5];
-       var lon3=words[6];
+       var lat1=Number(words[1]);
+       var lon1=Number(words[2]);
+       var lat2=Number(words[3]);
+       var lon2=Number(words[4]);
+       var lat3=Number(words[5]);
+       var lon3=Number(words[6]);
 
-       var lonlat1= new OpenLayers.LonLat(lon1,lat1).transform(epsg4326,epsg900913);
-       var lonlat2= new OpenLayers.LonLat(lon2,lat2).transform(epsg4326,epsg900913);
-       var lonlat3= new OpenLayers.LonLat(lon3,lat3).transform(epsg4326,epsg900913);
+       var lonlat1 = ol.proj.fromLonLat([lon1,lat1]);
+       var lonlat2 = ol.proj.fromLonLat([lon2,lat2]);
+       var lonlat3 = ol.proj.fromLonLat([lon3,lat3]);
 
-       var point1 = new OpenLayers.Geometry.Point(lonlat1.lon,lonlat1.lat);
-       var point2 = new OpenLayers.Geometry.Point(lonlat2.lon,lonlat2.lat);
-       var point3 = new OpenLayers.Geometry.Point(lonlat3.lon,lonlat3.lat);
+       var geometry = new ol.geom.LineString([lonlat1,lonlat2,lonlat3]);
 
-       var segments = new OpenLayers.Geometry.LineString([point1,point2,point3]);
+       var feature = new ol.Feature({geometry: geometry, dump: dump});
 
-       features.push(new OpenLayers.Feature.Vector(segments,{dump: dump},style));
+       feature.setStyle(style);
+
+       features.push(feature);
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","turns",lines.length-2);
 }
@@ -1116,17 +1019,13 @@ function runLimitSuccess(response)
 {
  var lines=response.responseText.split("\n");
 
- var node_style = new OpenLayers.Style({},{stroke: false,
-                                           pointRadius: 3,fillColor: "#FF0000",
-                                           cursor: "pointer"});
+ var node_style = new ol.style.Style({image: new ol.style.Circle({fill: new ol.style.Fill({color: "#FF0000"}),
+                                                                  radius: 3})});
 
- var segment_style = new OpenLayers.Style({},{fill: false,
-                                              strokeWidth: 2,strokeColor: "#FF0000",
-                                              cursor: "pointer"});
+ var segment_style = new ol.style.Style({stroke: new ol.style.Stroke({width: 2, color: "#FF0000"})});
 
  var features=[];
 
- var nodepoint;
  var nodelonlat;
 
  for(var line=0;line<lines.length;line++)
@@ -1134,60 +1033,57 @@ function runLimitSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat=words[1];
-       var lon=words[2];
+       var lat=Number(words[1]);
+       var lon=Number(words[2]);
        var number=words[3];
 
-       var lonlat= new OpenLayers.LonLat(lon,lat).transform(epsg4326,epsg900913);
-
-       var point = new OpenLayers.Geometry.Point(lonlat.lon,lonlat.lat);
+       var lonlat = ol.proj.fromLonLat([lon,lat]);
 
        if(number === undefined)
          {
-          nodelonlat=lonlat;
-          nodepoint = point;
+          nodelonlat = lonlat;
 
-          features.push(new OpenLayers.Feature.Vector(point,{dump: dump},node_style));
+          var geometry = new ol.geom.Point(nodelonlat);
+
+          var feature = new ol.Feature({geometry: geometry, dump: dump});
+
+          feature.setStyle(node_style);
+
+          features.push(feature);
          }
        else
          {
-          var segment = new OpenLayers.Geometry.LineString([nodepoint,point]);
+          geometry = new ol.geom.LineString([nodelonlat,lonlat]);
 
-          features.push(new OpenLayers.Feature.Vector(segment,{dump: dump},segment_style));
+          var feature = new ol.Feature({geometry: geometry, dump: dump});
 
-          var dlat = lonlat.lat-nodelonlat.lat;
-          var dlon = lonlat.lon-nodelonlat.lon;
+          feature.setStyle(segment_style);
+
+          features.push(feature);
+
+          var dlat = lonlat[1]-nodelonlat[1];
+          var dlon = lonlat[0]-nodelonlat[0];
           var dist = Math.sqrt(dlat*dlat+dlon*dlon)/120;
 
-          point = new OpenLayers.Geometry.Point(nodelonlat.lon+dlon/dist,nodelonlat.lat+dlat/dist);
+          geometry = new ol.geom.Point([nodelonlat[0]+dlon/dist, nodelonlat[1]+dlat/dist]);
 
-          features.push(new OpenLayers.Feature.Vector(point,{dump: dump},
-                                                      new OpenLayers.Style({},{externalGraphic: "icons/limit-" + number + ".png",
-                                                                               graphicYOffset: -9,
-                                                                               graphicWidth: 19,
-                                                                               graphicHeight: 19})));
+          var style = new ol.style.Style({image: new ol.style.Icon({src: "icons/limit-" + number + ".png",
+                                                              anchor: [0.5,0.5]})});
+
+          var feature = new ol.Feature({geometry: geometry, dump: dump});
+
+          feature.setStyle(style);
+
+          features.push(feature);
          }
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","limit",lines.length-2);
 }
@@ -1201,9 +1097,7 @@ function runPropertySuccess(response)
 {
  var lines=response.responseText.split("\n");
 
- var style = new OpenLayers.Style({},{fill: false,
-                                      strokeWidth: 2,strokeColor: "#FF0000",
-                                      cursor: "pointer"});
+ var style = new ol.style.Style({stroke: new ol.style.Stroke({width: 2, color: "#FF0000"})});
 
  var features=[];
 
@@ -1212,41 +1106,29 @@ function runPropertySuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat1=words[1];
-       var lon1=words[2];
-       var lat2=words[3];
-       var lon2=words[4];
+       var lat1=Number(words[1]);
+       var lon1=Number(words[2]);
+       var lat2=Number(words[3]);
+       var lon2=Number(words[4]);
 
-       var lonlat1= new OpenLayers.LonLat(lon1,lat1).transform(epsg4326,epsg900913);
-       var lonlat2= new OpenLayers.LonLat(lon2,lat2).transform(epsg4326,epsg900913);
+       var lonlat1 = ol.proj.fromLonLat([lon1,lat1]);
+       var lonlat2 = ol.proj.fromLonLat([lon2,lat2]);
 
-       var point1 = new OpenLayers.Geometry.Point(lonlat1.lon,lonlat1.lat);
-       var point2 = new OpenLayers.Geometry.Point(lonlat2.lon,lonlat2.lat);
+       var geometry = new ol.geom.LineString([lonlat1,lonlat2]);
 
-       var segment = new OpenLayers.Geometry.LineString([point1,point2]);
+       var feature = new ol.Feature({geometry: geometry, dump: dump});
 
-       features.push(new OpenLayers.Feature.Vector(segment,{dump: dump},style));
+       feature.setStyle(style);
+
+       features.push(feature);
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","property",lines.length-2);
 }
@@ -1260,9 +1142,8 @@ function runErrorlogSuccess(response)
 {
  var lines=response.responseText.split("\n");
 
- var style = new OpenLayers.Style({},{stroke: false,
-                                      pointRadius: 3,fillColor: "#FF0000",
-                                      cursor: "pointer"});
+ var style = new ol.style.Style({image: new ol.style.Circle({fill: new ol.style.Fill({color: "#FF0000"}),
+                                                             radius: 3})});
 
  var features=[];
 
@@ -1271,35 +1152,24 @@ function runErrorlogSuccess(response)
     var words=lines[line].split(" ");
 
     if(line === 0)
-      {
-       var lat1=words[0];
-       var lon1=words[1];
-       var lat2=words[2];
-       var lon2=words[3];
-
-       var bounds = new OpenLayers.Bounds(lon1,lat1,lon2,lat2).transform(epsg4326,epsg900913);
-
-       box = new OpenLayers.Marker.Box(bounds);
-
-       layerBoxes.addMarker(box);
-      }
+       addBox(words);
     else if(words[0] !== "")
       {
        var dump=words[0];
-       var lat=words[1];
-       var lon=words[2];
+       var lat=Number(words[1]);
+       var lon=Number(words[2]);
 
-       var lonlat = new OpenLayers.LonLat(lon,lat).transform(epsg4326,epsg900913);
+       var geometry = new ol.geom.Point(ol.proj.fromLonLat([lon,lat]));
 
-       var point = new OpenLayers.Geometry.Point(lonlat.lon,lonlat.lat);
+       var feature = new ol.Feature({geometry: geometry, dump: dump});
 
-       features.push(new OpenLayers.Feature.Vector(point,{dump: dump},style));
+       feature.setStyle(style);
+
+       features.push(feature);
       }
    }
 
- select.activate();
-
- layerVectors.addFeatures(features);
+ layerVectors.getSource().addFeatures(features);
 
  displayStatus("data","errorlogs",lines.length-2);
 }
